==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/runtime/gc_modron_startup/mminit.h <==

/*******************************************************************************
 * Copyright (c) 1991, 2020 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

/**
 * @file
 * @ingroup GC_Modron_Startup
 */

#if !defined(MMINIT_H_)
#define MMINIT_H_

#include "j9lib.h"
#include "jniport.h"

struct J9JavaVM;
struct J9VMThread;

#ifdef __cplusplus
extern "C" {
#endif

jint gcInitializeDefaults(J9JavaVM* vm);
void gcCleanupInitializeDefaults(OMR_VM* omrVM);

jint gcInitializeHeapStructures(J9JavaVM* vm);
void gcCleanupHeapStructures(J9JavaVM* vm);

jint triggerGCInitialized(J9VMThread* vmThread);

void gcExpandHeapOnStartup(J9JavaVM *javaVM);

#ifdef __cplusplus
} /* extern "C" { */
#endif

#endif /* MMINIT_H_ */

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/runtime/gc_modron_startup/mminit.h <==

/*******************************************************************************
 * Copyright IBM Corp. and others 1991
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 *******************************************************************************/

/**
 * @file
 * @ingroup GC_Modron_Startup
 */

#if !defined(MMINIT_H_)
#define MMINIT_H_

#include "j9lib.h"
#include "jniport.h"

struct J9JavaVM;
struct J9VMThread;

#ifdef __cplusplus
extern "C" {
#endif

jint gcInitializeDefaults(J9JavaVM* vm);

void initializeIndexableObjectHeaderSizes(J9JavaVM* vm);
#if defined(J9VM_ENV_DATA64)
void setIndexableObjectHeaderSizeWithDataAddress(J9JavaVM* vm);
#endif /* defined(J9VM_ENV_DATA64) */
void setIndexableObjectHeaderSizeWithoutDataAddress(J9JavaVM* vm);

void gcCleanupInitializeDefaults(OMR_VM* omrVM);

jint gcInitializeHeapStructures(J9JavaVM* vm);
void gcCleanupHeapStructures(J9JavaVM* vm);

jint triggerGCInitialized(J9VMThread* vmThread);

void gcExpandHeapOnStartup(J9JavaVM *javaVM);

#ifdef __cplusplus
} /* extern "C" { */
#endif

#endif /* MMINIT_H_ */
